@@ -89,18 +89,18 @@ func (a *Aliases) Resolve(p *cmd.Interpreter) (*client.GVR, bool) {
 	}
 
 	if gvr.IsK8sRes() {
-		p.Reset(strings.Replace(p.GetLine(), p.Cmd(), gvr.String(), 1))
+		p.Reset(strings.Replace(p.GetLine(), p.Cmd(), gvr.String(), 1), p.Cmd())
 		return gvr, true
 	}
 
-	for gvr.IsCommand() {
+	for gvr.IsAlias() {
 		ap := cmd.NewInterpreter(gvr.String())
 		gvr, ok = a.Get(ap.Cmd())
 		if !ok {
 			return gvr, false
 		}
 		ap.Merge(p)
-		p.Reset(strings.Replace(ap.GetLine(), ap.Cmd(), gvr.String(), 1))
+		p.Reset(strings.Replace(ap.GetLine(), ap.Cmd(), gvr.String(), 1), ap.Cmd())
 	}
 
 	return gvr, true
