@@ -12,17 +12,17 @@ import (
 )
 
 func TestAppGetCmd(t *testing.T) {
-	a := ui.NewApp(mock.NewMockConfig(), "")
+	a := ui.NewApp(mock.NewMockConfig(t), "")
 	a.Init()
-	a.CmdBuff().SetText("blee", "")
+	a.CmdBuff().SetText("blee", "", true)
 
 	assert.Equal(t, "blee", a.GetCmd())
 }
 
 func TestAppInCmdMode(t *testing.T) {
-	a := ui.NewApp(mock.NewMockConfig(), "")
+	a := ui.NewApp(mock.NewMockConfig(t), "")
 	a.Init()
-	a.CmdBuff().SetText("blee", "")
+	a.CmdBuff().SetText("blee", "", true)
 	assert.False(t, a.InCmdMode())
 
 	a.CmdBuff().SetActive(false)
@@ -30,9 +30,9 @@ func TestAppInCmdMode(t *testing.T) {
 }
 
 func TestAppResetCmd(t *testing.T) {
-	a := ui.NewApp(mock.NewMockConfig(), "")
+	a := ui.NewApp(mock.NewMockConfig(t), "")
 	a.Init()
-	a.CmdBuff().SetText("blee", "")
+	a.CmdBuff().SetText("blee", "", true)
 
 	a.ResetCmd()
 
@@ -40,18 +40,18 @@ func TestAppResetCmd(t *testing.T) {
 }
 
 func TestAppHasCmd(t *testing.T) {
-	a := ui.NewApp(mock.NewMockConfig(), "")
+	a := ui.NewApp(mock.NewMockConfig(t), "")
 	a.Init()
 
 	a.ActivateCmd(true)
 	assert.False(t, a.HasCmd())
 
-	a.CmdBuff().SetText("blee", "")
+	a.CmdBuff().SetText("blee", "", true)
 	assert.True(t, a.InCmdMode())
 }
 
 func TestAppGetActions(t *testing.T) {
-	a := ui.NewApp(mock.NewMockConfig(), "")
+	a := ui.NewApp(mock.NewMockConfig(t), "")
 	a.Init()
 
 	a.GetActions().Add(ui.KeyZ, ui.KeyAction{Description: "zorg"})
@@ -60,7 +60,7 @@ func TestAppGetActions(t *testing.T) {
 }
 
 func TestAppViews(t *testing.T) {
-	a := ui.NewApp(mock.NewMockConfig(), "")
+	a := ui.NewApp(mock.NewMockConfig(t), "")
 	a.Init()
 
 	vv := []string{"crumbs", "logo", "prompt", "menu"}
