@@ -18,7 +18,7 @@ type Group struct {
 }
 
 // NewGroup returns a new subject viewer.
-func NewGroup(gvr client.GVR) ResourceViewer {
+func NewGroup(gvr *client.GVR) ResourceViewer {
 	g := Group{ResourceViewer: NewBrowser(gvr)}
 	g.AddBindKeysFn(g.bindKeys)
 	g.SetContextFn(g.subjectCtx)
@@ -34,7 +34,7 @@ func (g *Group) bindKeys(aa *ui.KeyActions) {
 	})
 }
 
-func (g *Group) subjectCtx(ctx context.Context) context.Context {
+func (*Group) subjectCtx(ctx context.Context) context.Context {
 	return context.WithValue(ctx, internal.KeySubjectKind, "Group")
 }
 
